<?php
/**
 * Mottle base inclusion file.
 *
 * This file brings in all of the dependencies that every Mottle script will
 * need and sets up objects that all scripts use.
 *
 * $Horde: mottle/lib/base.php,v 1.20 2008-01-02 11:13:48 jan Exp $
 *
 * Copyright 2001-2008 The Horde Project (http://www.horde.org/)
 *
 * @author Daniel Vandal <dvandal@infoteck.qc.ca>
 */

/* Check for a prior definition of HORDE_BASE (perhaps by an
 * auto_prepend_file definition for site customization). */
if (!defined('HORDE_BASE')) {
    @define('HORDE_BASE', dirname(__FILE__) . '/../..');
}

/* Load the Horde Framework core, and set up inclusion paths. */
require_once HORDE_BASE . '/lib/core.php';

/* Registry. */
$registry = &Registry::singleton();
if (is_a(($pushed = $registry->pushApp('mottle', !defined('AUTH_HANDLER'))), 'PEAR_Error')) {
    if ($pushed->getCode() == 'permission_denied') {
        Horde::authenticationFailureRedirect();
    }
    Horde::fatal($pushed, __FILE__, __LINE__, false);
}
$conf = &$GLOBALS['conf'];
@define('MOTTLE_TEMPLATES', $registry->get('templates'));

/* Notification system. */
$notification = &Notification::singleton();
$notification->attach('status');

/* Find the base file path of Mottle. */
@define('MOTTLE_BASE', dirname(__FILE__) . '/..');

/* Mottle base libraries. */
require_once MOTTLE_BASE . '/lib/Mottle.php';

/* Help. */
require_once 'Horde/Help.php';

/* Create a share instance. */
require_once 'Horde/Share.php';
$GLOBALS['mottle_shares'] = &Horde_Share::singleton($registry->getApp());

/* If this share doesn't exist then create it. */
if (Auth::getAuth() && !$GLOBALS['mottle_shares']->exists(Auth::getAuth())) {
    require_once 'Horde/Identity.php';
    $identity = &Identity::singleton();
    $name = $identity->getValue('fullname');
    if (trim($name) == '') {
        $name = Auth::removeHook(Auth::getAuth());
    }
    $share = $GLOBALS['mottle_shares']->newShare(Auth::getAuth());
    $share->set('name', _("MOTD"));
    $GLOBALS['mottle_shares']->addShare($share);
}

/* Start output compression. */
Horde::compressOutput();
